.. automodule:: cmomy
   :no-members:
   :no-inherited-members:
   :no-special-members:




Moments of :class:`numpy.ndarray`
=================================

.. autosummary::
   :toctree: generated/

   CentralMoments
   central_moments


Moments of :class:`xarray.DataArray`
====================================

.. autosummary::
   :toctree: generated/

   xCentralMoments
   xcentral_moments
